Usage
=====

**Taurenmd** provides a command-line interface to many routines in Molecular Dynamics data analysis, therefore **taurenmd** runs by executing one-line and argument-rich commands on the :code:`terminal`.

**Taurenmd** uses other scientific libraries to handle and generate Molecular Dynamics data. You SHOULD by all means cite also the other libraries when using taurenmd. Please refer to our :ref:`citing` section for more detailed instructions.

We have several *command* interfaces already implemented, our :ref:`Command-line interfaces` page documents in detail each and every of them. 

:IMPORTANT: Do not forget to activate the python environment where you installed *taurenmd* in case it is not yet activated. Please read through our :ref:`Installation` page.

.. automodule:: taurenmd.cli
